@@ -14,7 +14,8 @@
 
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+# 02111-1307, USA.
 
 # Reads from stdin if no files are given.
 # Writes to stdout.
@@ -26,7 +27,7 @@ usage="\
 Usage: ifnames [-h] [--help] [-m dir] [--macrodir=dir] [--version] [file...]"
 show_version=no
 
-test -z "$AC_MACRODIR" && AC_MACRODIR=/usr/local/gnu/share/autoconf
+: ${AC_MACRODIR=@datadir@}
 
 while test $# -gt 0; do
   case "$1" in 
